package com.iamberry.wechat.service.apparatus;

import com.github.pagehelper.PageHelper;
import com.iamberry.wechat.core.entity.admin.ShopSystemRule;
import com.iamberry.wechat.core.entity.apparatus.Apparatus;
import com.iamberry.wechat.core.entity.integral.IntegralConfig;
import com.iamberry.wechat.core.entity.integral.StayIntegral;
import com.iamberry.wechat.core.entity.integral.UseIntegral;
import com.iamberry.wechat.core.entity.member.Member;
import com.iamberry.wechat.core.entity.page.PageRequest;
import com.iamberry.wechat.core.entity.page.PagedResult;
import com.iamberry.wechat.core.entity.product.ProductRelatedRstProduce;
import com.iamberry.wechat.face.apparatus.ApparatusService;
import com.iamberry.wechat.service.mapper.ApparatusMapper;
import com.iamberry.wechat.service.mapper.MemberMapper;
import com.iamberry.wechat.service.mapper.SystemMapper;
import com.iamberry.wechat.service.mapper.UseIntegralMapper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import util.PageUtil;

import java.util.Calendar;
import java.util.List;

/**
 * Created by liuzhiwei on 2017/12/28.
 */
@Service
public class ApparatusServiceImpl implements ApparatusService {


    private Logger logger = LoggerFactory.getLogger(ApparatusServiceImpl.class);

    @Autowired
    private ApparatusMapper apparatusMapper;
    @Autowired
    private SystemMapper systemMapper;
    @Autowired
    private UseIntegralMapper useIntegralMapper;
    @Autowired
    private MemberMapper memberMapper;
    @Autowired
    private ApparatusService apparatusService;



    @Override
    public List<Apparatus> listApparatusPage(Apparatus apparatus) {
        return apparatusMapper.listApparatusPage(apparatus);
    }

    @Override
    public PagedResult<Apparatus> listApparatusPageByAdmin(PageRequest<Apparatus> pageRequest) {
        PageHelper.startPage(pageRequest.getPageNO(), pageRequest.getPageSize(), pageRequest.isPageTotal());
        List<Apparatus> detedctList = apparatusMapper.listApparatusPageByAdmin(pageRequest.getData());
        return PageUtil.getPage(detedctList);
    }


    @Override
    public Integer addApparatus(Apparatus apparatus) {
        return apparatusMapper.addApparatus(apparatus);
    }

    @Override
    @Transactional
    public boolean registerMember(Apparatus apparatus, Member member) {

        //获取会员信息，判断是否已经注册会员
        Member memberInfo = memberMapper.getMemberByUserOpenId(member.getUserOpenid());
        if(memberInfo == null){
            throw new RuntimeException("获取会员信息失败");
        }

        if(memberInfo.getUserBirthDate() != null){
            member.setUserBirthDate(null);
        }

        //添加机器信息
        int num = apparatusMapper.addApparatus(apparatus);
        if(num > 0){
            //这里判断是否是会员 1.会员 2.普通用户
            if(memberInfo.getUserIdentity() == 2){
                //赠送新注册积分
                apparatusService.addStayIntegral(member.getUserOpenid(),1,0,"",apparatus.getColorId());
            }
            //赠送400新增牙刷积分
            apparatusService.addStayIntegral(member.getUserOpenid(),2,0,"",apparatus.getColorId());
           //修改用户信息
            member.setUserIdentity(1);
            if(memberMapper.updateMemberByUserId(member) < 1){
                throw new RuntimeException("修改用户信息失败");
            }
        } else {
            throw new RuntimeException("绑定牙刷失败");
        }
        return true;
    }


    /**
     * 获取数据库配置的积分数量
     * @param id
     * @return
     */
    public IntegralConfig getIntegralId(Integer id){
        //新增加牙刷获取积分id
        ShopSystemRule shopSystemRule = systemMapper.selectOneShopRuleById(id);
        if (shopSystemRule == null) {
            return null;
        }
        IntegralConfig config = new IntegralConfig();
        config.setIntegralConfigId(shopSystemRule.getRuleNum().intValue());
        //获取会员获取积分配置信息
        List<IntegralConfig> configList = useIntegralMapper.listIntegralConfig(config);
        if (configList == null || configList.size() == 0) {
            return null;
        }
        return configList.get(0);
    }

    @Override
    public Apparatus getApparatus(Apparatus apparatus) {
        return apparatusMapper.getApparatus(apparatus);
    }

    @Override
    public Integer getColorIdByProductId(String productId) {
        return apparatusMapper.getColorIdByProductId(productId);
    }

    /**
     * 添加待入账积分统一调用该接口
     * @param openId
     * @param IntegralType 1.新注册会员送一百积分  2.新增牙刷赠送400积分 3.购买牙刷，赠送订单金额乘以2的积分
     * @param orderAllIntegral  订单金额  IntegralType为3时有值
     * @param orderId  订单id  IntegralType为3时有值
     * @return
     */
    @Override
    @Transactional
    public boolean addStayIntegral(String openId,Integer IntegralType,Integer orderAllIntegral,String orderId,Integer cololId){
        if(openId == null||openId.equals("") || IntegralType < 1){
            throw new RuntimeException("入账积分类型为空或openid为空");
        }
        IntegralConfig integralConfig = null;
        StayIntegral stayIntegral = new StayIntegral();
        Integer stayNumber = 0;
        Calendar calendar = Calendar.getInstance();
        switch (IntegralType){
            case 1:
                //新注册会员积分数量
                integralConfig = getIntegralId(247);
                stayNumber = integralConfig.getIntegralConfigNumber();
                //规则表查询新注册会员和新增牙刷积分到账时间（多少天到账）
                ShopSystemRule registeredSystemRule=systemMapper.selectOneShopRuleById(251);
                calendar.set(Calendar.DAY_OF_MONTH,calendar.get(Calendar.DAY_OF_MONTH)+registeredSystemRule.getRuleNum().intValue());
                stayIntegral.setStayRecordedTime(calendar.getTime());
                break;
            case 2:
                //新增加牙刷赠送积分数量 根据产品颜色id查询规则表
                IntegralConfig config = new IntegralConfig();
                config.setIntegralConfigColorId(cololId);
                //获取会员获取积分配置信息
                List<IntegralConfig> configList = useIntegralMapper.listIntegralConfig(config);
                integralConfig = configList.get(0);
                stayNumber = integralConfig.getIntegralConfigNumber();
                //规则表查询新注册会员和新增牙刷积分到账时间（多少天到账）
                ShopSystemRule addToothRule=systemMapper.selectOneShopRuleById(251);
                calendar.set(Calendar.DAY_OF_MONTH,calendar.get(Calendar.DAY_OF_MONTH)+addToothRule.getRuleNum().intValue());
                stayIntegral.setStayRecordedTime(calendar.getTime());
                break;
            case 3:
                if(orderAllIntegral == 0){
                    break;
                }
                integralConfig = getIntegralId(250);
                stayNumber = orderAllIntegral;
                stayIntegral.setOrderId(orderId);
                //规则表查询新注册会员和新增牙刷积分到账时间（多少天到账）
                ShopSystemRule shopSystemRule=systemMapper.selectOneShopRuleById(252);
                Integer day = shopSystemRule.getRuleNum().intValue();
                calendar.set(Calendar.DAY_OF_MONTH,calendar.get(Calendar.DAY_OF_MONTH)+day);
                stayIntegral.setStayRecordedTime(calendar.getTime());
                break;
            default:
                 break;
        }
        if(integralConfig == null){
            throw new RuntimeException("积分数量为空");
        }
        stayIntegral.setUserOpenId(openId);
        stayIntegral.setConfigId(integralConfig.getIntegralConfigId());
        stayIntegral.setStayNumber(stayNumber);

        stayIntegral.setStayStatus(1);
        Integer msg = memberMapper.insertStayIntegral(stayIntegral);
        if(msg > 0){
            //添加待入账积分
            Member memberInfo = memberMapper.getMemberByUserOpenId(openId);
            memberInfo.setUserStayIntegral(stayNumber);
            if(memberMapper.updateUserStayIntegralByOpenId(memberInfo) > 0){
                //添加日志
                UseIntegral useIntegral = new UseIntegral();
                useIntegral.setConfigId(integralConfig.getIntegralConfigId());
                useIntegral.setUserOpenId(openId);
                useIntegral.setIntegralType(3);
                useIntegral.setStayId(stayIntegral.getStayId());
                useIntegral.setIntegralNumber(stayNumber);
                useIntegral.setIntegralBeforeNumber(memberInfo.getUserSurplusIntegral());
                useIntegral.setIntegralEndNumber(memberInfo.getUserSurplusIntegral());
                useIntegral.setIntegralRemarks(integralConfig.getIntegralConfigName());
                //添加积分获取日志信息
                if(useIntegralMapper.addUseIntegral(useIntegral) < 1){
                    throw new RuntimeException("添加积分日志失败");
                }
            }else{
                throw new RuntimeException("修改用户待入账积分失败");
            }
        }else{
            throw new RuntimeException("增加待入账失败");
        }
        return true;
    }

    @Override
    public Integer addColorIdByProductId(ProductRelatedRstProduce productRelatedRstProduce) {
        return apparatusMapper.addColorIdByProductId(productRelatedRstProduce);
    }

    @Override
    @Transactional
    public Integer delTooth(String code) {
        Integer flag = 0;
        Integer stayStatus=0; //待入账状态
        Integer stayIntegraNum = 0; //积分
        Apparatus apparatus = new Apparatus();
        apparatus.setApparatusBarcode(code);
        List<Apparatus> apparatusList = apparatusMapper.listApparatusPage(apparatus);
        if(apparatusList == null || apparatusList.size() < 1){
            throw new RuntimeException("删除失败，未查询出牙刷");
        }
        if(apparatusList != null && apparatusList.size() > 1){
            throw new RuntimeException("删除失败，查出多个牙刷");
        }
        apparatus = apparatusList.get(0);
        if(apparatus.getColorId() == null || apparatus.getUserOpenid() == null){
            throw new RuntimeException("删除失败，绑定牙刷有错误，请联系技术删除");
        }

        //如果该用户只有一个牙刷，则不允许删除
        Apparatus appar = new Apparatus();
        appar.setUserOpenid(apparatus.getUserOpenid());
        List<Apparatus> apparList = apparatusMapper.listApparatusPage(appar);
        if(apparList.size() < 2){
            throw new RuntimeException("删除失败，该用户只有一个牙刷，不允许直接删除！");
        }

        //查询配置ID
        IntegralConfig integralConfig = new IntegralConfig();
        integralConfig.setIntegralConfigColorId(apparatus.getColorId());
        List<IntegralConfig>  integralConfigList = useIntegralMapper.listIntegralConfig(integralConfig);
        if(integralConfigList == null || integralConfigList.size() < 1){
            throw new RuntimeException("删除失败，未查询出配置项");
        }
        if(integralConfigList != null && integralConfigList.size() > 1){
            throw new RuntimeException("删除失败，查出多个颜色配置");
        }
        integralConfig = integralConfigList.get(0);

        //查询待入账
        StayIntegral stayIntegral = new StayIntegral();
        stayIntegral.setConfigId(integralConfig.getIntegralConfigId());
        stayIntegral.setUserOpenId(apparatus.getUserOpenid());
        List<StayIntegral>  stayIntegralList = useIntegralMapper.listStayIntegral(stayIntegral);
        if(stayIntegralList == null || stayIntegralList.size() < 1){
            throw new RuntimeException("删除失败，未查询出待入账");
        }
        if(stayIntegralList != null && stayIntegralList.size() > 1){
            //因为系统没有牙刷绑定与待入账积分绑定关系，所以只能对比时间来判断是删除的那个牙刷，下面是比较时间计算那个时间相近
            long num = 0;
            for(int i=0;i<stayIntegralList.size();i++){
                StayIntegral si = stayIntegralList.get(i);
                long item = si.getStayCreateTime().getTime() - apparatus.getApparatusCreateTime().getTime();
                if(item < 0){
                    item *= -1;  //计算绝对值
                }
                if(i == 0 ){
                    num = item;
                    stayIntegral = stayIntegralList.get(i);
                }else{
                    if(item < num){
                        num = item;
                        stayIntegral = stayIntegralList.get(i);
                    }
                }
            }
        }else{
            stayIntegral = stayIntegralList.get(0);
        }

        stayStatus = stayIntegral.getStayStatus();
        stayIntegraNum = stayIntegral.getStayNumber();

        //修改待入账
        StayIntegral si = new StayIntegral();
        si.setStayId(stayIntegral.getStayId());
        si.setStayStatus(4);
        flag = useIntegralMapper.updatestayIntegralStatus(si);
        if(flag < 1){
            throw new RuntimeException("删除失败，修改待入账失败");
        }

        //修改日志
        UseIntegral useIntegral = new UseIntegral();
        useIntegral.setStayId(stayIntegral.getStayId());
        useIntegral.setIntegralType(4);
        flag = useIntegralMapper.updateUseIntegra(useIntegral);
        if(flag < 1){
            throw new RuntimeException("删除失败，修改入账记录失败");
        }

        Member member = memberMapper.getMemberByUserOpenId(apparatus.getUserOpenid());
        if(member == null){
            throw new RuntimeException("删除失败，查询用户失败");
        }
        Member me = new Member();
        me.setUserOpenid(member.getUserOpenid());
        me.setUserId(member.getUserId());

        //修改积分
        String integraType = "";
        if(stayStatus == 1){ //1：待入账2：已入账3：订单取消/退货,撤回4：取消   、userStayIntegral
            integraType = "待入账";
            if(member.getUserStayIntegral() >= stayIntegraNum){
                me.setUserStayIntegral(member.getUserStayIntegral() - stayIntegraNum);
            }else{
                throw new RuntimeException("删除失败，客户积分不正确"); //可能查询出错误的积分日志
            }
        }else if(stayStatus == 2){  //2：已入账
            integraType = "已入账";
            if(member.getUserIntegral() >= stayIntegraNum && member.getUserSurplusIntegral() >= stayIntegraNum){
                me.setUserIntegral(member.getUserIntegral() - stayIntegraNum);
                me.setUserSurplusIntegral(member.getUserSurplusIntegral() - stayIntegraNum);
            }else{
                throw new RuntimeException("删除失败，客户积分不正确");  //可能查询出错误的积分日志
            }
        }else{
            integraType = "其他";
            throw new RuntimeException("删除失败，待入账状态不正确");
        }
        flag = memberMapper.update(me);
        if(flag < 1){
            throw new RuntimeException("删除失败，修改积分失败");
        }

        //删除牙刷
        flag = apparatusMapper.delApparatus(code);
        if(flag < 1){
            throw new RuntimeException("删除失败，删除牙刷失败");
        }

        logger.info("删除牙刷成功；牙刷编号："+code+";客户openId："+apparatus.getUserOpenid()+";减去积分："+stayIntegraNum+";减去积分类型:"+integraType);
        return flag;
    }


}
