package com.iamberry.wechat.handles.activity;

import com.iamberry.app.tool.log.RatFWLogger;
import com.iamberry.wechat.core.entity.ResultMsg;
import com.iamberry.wechat.core.entity.WechatUtils;
import com.iamberry.wechat.core.entity.activity.Festival;
import com.iamberry.wechat.core.entity.activity.FestivalHelp;
import com.iamberry.wechat.core.entity.member.Member;
import com.iamberry.wechat.face.member.MemberService;
import com.iamberry.wechat.service.activity.FestivalHelpServiceImpl;
import com.iamberry.wechat.service.activity.FestivalServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * @author wxm
 * Class Description: 年货节活动
 */
@Controller
@RequestMapping("/wechat/festival")
public class FestivalHandler {

	@Autowired
	private MemberService memberService;
	@Autowired
	private RatFWLogger logger;
	@Autowired
	private FestivalServiceImpl festivalService;
	@Autowired
	private FestivalHelpServiceImpl festivalHelpService;

	/**
	 * 进入活动页面判断该用户是否已参加，已参加展示已助力人数和优惠券信息
	 * @param req
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/to_festival")
	public ResultMsg toFestival(HttpServletRequest req){
		ResultMsg rm = ResultMsg.getSuccess();

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());

		Festival festival = new Festival();
		festival.setFestivalOpenId(member.getUserOpenid());
		List<Festival> festivalList = festivalService.getFestivalList(festival);
		if(festivalList != null && festivalList.size()>0){
			festival = festivalList.get(0);
		}else{
			rm.addData("status",2);
			rm.addData("msg","未参与活动，可领取优惠券");
			return rm;
		}

		FestivalHelp festivalHelp = new FestivalHelp();
		festivalHelp.setFestivalId(festival.getFestivalId());
		List<FestivalHelp> festivalHelpList = festivalHelpService.getFestivalHelpList(festivalHelp);

		rm.addData("status",1);
		rm.addData("msg","已参与活动");
		rm.addData("member",member);
		rm.addData("festival",festival);
		rm.addData("festivalHelpList",festivalHelpList);
		return rm;
	}

	/**
	 * 参与活动+领取优惠券
	 * @param req
	 * @return
	 */
	@ResponseBody
	@RequestMapping("/receive_activity")
	public synchronized ResultMsg getColorPatterns(HttpServletRequest req, String openid){
		ResultMsg rm = ResultMsg.getSuccess();

		Member member = WechatUtils.getUserBySession(req);
		member = memberService.getMemberByUserOpenId(member.getUserOpenid());

		if(openid == null || "".equals(openid)){
			rm = ResultMsg.getError();
			rm.setMessage("参与活动出错，请重试或联系客服！");
			return rm;
		}else{
			if(!"X".equals(openid)){
				Member oldmember = memberService.getMemberByUserOpenId(openid);
				if(oldmember == null || oldmember.getUserOpenid() == null){
					rm = ResultMsg.getError();
					rm.setMessage("参与活动出错，请重试或联系客服！");
					return rm;
				}
			}
		}
		Integer flag = 0;
		Festival festival = new Festival();
		festival.setFestivalOpenId(member.getUserOpenid());
		List<Festival> festivalList = festivalService.getFestivalList(festival);
		if(festivalList == null || festivalList.size()<1){
			//未参与活动，可参与活动
			Festival newFestival = new Festival();
			newFestival.setFestivalOpenId(member.getUserOpenid());
			newFestival.setSharerOpenId(openid);
			try{
				flag = festivalService.save(newFestival);
			}catch (RuntimeException e){
				e.printStackTrace();
				rm = ResultMsg.getError();
				rm.setMessage(e.getMessage());
				return rm;
			}
		}
		rm.setMessage("领取成功");
		return rm;
	}

}
